## Limited support for WrapDB v1

WrapDB v1 has been discontinued for several years, Meson will now print a
deprecation warning if a v1 URL is still being used. Wraps can be updated to
latest version using `meson wrap update` command.
